@@ -444,6 +444,27 @@ gdm_slave_save_root_windows (GdmSlave *slave)
         XSync (slave->priv->server_display, False);
 }
 
+static XRRScreenResources *
+get_screen_resources (Display *dpy)
+{
+        int major = 0, minor = 0;
+
+        if (!XRRQueryVersion(dpy, &major, &minor)) {
+                return NULL;
+        }
+
+        if (major > 1) {
+                return NULL;
+        }
+
+        if (minor >= 3) {
+                return XRRGetScreenResourcesCurrent (dpy,
+                                                     DefaultRootWindow (dpy));
+        }
+
+        return XRRGetScreenResources (dpy, DefaultRootWindow (dpy));
+}
+
 static void
 determine_initial_cursor_position (GdmSlave *slave,
                                    int      *x,
@@ -454,15 +475,15 @@ determine_initial_cursor_position (GdmSlave *slave,
         int i;
 
         /* If this function fails for whatever reason,
-         * put the pointer in the upper left corner of the
-         * first monitor
+         * put the pointer in the lower right corner of the screen.
          */
-        *x = 0;
-        *y = 0;
+        *x = .9 * DisplayWidth (slave->priv->server_display,
+                                DefaultScreen (slave->priv->server_display));
+        *y = .9 * DisplayHeight (slave->priv->server_display,
+                                 DefaultScreen (slave->priv->server_display));
 
         gdm_error_trap_push ();
-        resources = XRRGetScreenResources (slave->priv->server_display,
-                                           DefaultRootWindow (slave->priv->server_display));
+        resources = get_screen_resources (slave->priv->server_display);
         primary_output = XRRGetOutputPrimary (slave->priv->server_display,
                                               DefaultRootWindow (slave->priv->server_display));
         gdm_error_trap_pop ();
